-- ---------------------
-- GEOMETRISCHER VERBUND
-- ---------------------

--- Join mit nur einem Index 

-- Index von centrum lschen:
DROP INDEX Gemeinden_centrum_ix;

-- Filter:
SELECT /*+ ORDERED */ COUNT(*)
FROM Gemeinden g INNER JOIN Ortsnetze n
ON SDO_FILTER (n.gebiet, g.centrum,'querytype=WINDOW') = 'TRUE';

-- Exakter Test:
SELECT /*+ ORDERED */ COUNT(*)
FROM Gemeinden g INNER JOIN Ortsnetze n
ON SDO_RELATE (n.gebiet, g.centrum,'mask=CONTAINS, querytype=WINDOW') = 'TRUE';

--- Join mit zwei Indexen

-- Index erzeugen:
CREATE INDEX Gemeinden_centrum_ix
ON Gemeinden(centrum)
INDEXTYPE IS MDSYS.SPATIAL_INDEX;

-- Filter:
SELECT /*+ ORDERED */ COUNT(*)
FROM Gemeinden g INNER JOIN Ortsnetze n
ON SDO_FILTER (n.gebiet, g.centrum,'querytype=JOIN') = 'TRUE';

-- Exakter Test:
SELECT /*+ ORDERED */ COUNT(*)
FROM Gemeinden g INNER JOIN Ortsnetze n
ON SDO_RELATE (n.gebiet, g.centrum, 'mask=CONTAINS, querytype=JOIN') = 'TRUE';


-- ------------------------
-- NCHSTE-NACHBARN-ANFRAGE
-- ------------------------

--- mit Anfrageobjekt

SELECT n.name
FROM Ortsnetze n INNER JOIN Gemeinden g
ON SDO_NN (n.gebiet,g.centrum,'sdo_num_res=12') = 'TRUE'
WHERE g.name = 'Syke';

-- mit Anfrageobjekt und Entfernungsausgabe

SELECT n.name, MDSYS.SDO_NN_DISTANCE(1)
FROM Ortsnetze n INNER JOIN Gemeinden g
ON SDO_NN (n.gebiet,g.centrum,'sdo_num_res=12 unit=km',1) = 'TRUE'
WHERE g.name = 'Syke'
ORDER BY MDSYS.SDO_NN_DISTANCE(1);

-- mit zustzlichen Bedingungen

-- unvollstndige NNQ:
SELECT n.name, MDSYS.SDO_NN_DISTANCE(1)
FROM Ortsnetze n INNER JOIN Gemeinden g
ON SDO_NN (n.gebiet,g.centrum,'sdo_num_res=5 unit=km',1) = 'TRUE'
WHERE g.name = 'Syke' AND n.name <> 'Syke'
ORDER BY MDSYS.SDO_NN_DISTANCE(1);

-- NNQ mit SDO_BATCH_SIZE:
SELECT n.name, MDSYS.SDO_NN_DISTANCE(1)
FROM Ortsnetze n INNER JOIN Gemeinden g
ON SDO_NN (n.gebiet,g.centrum,'sdo_batch_size=10 unit=km',1) = 'TRUE'
WHERE g.name = 'Syke' AND n.name <> 'Syke' AND ROWNUM <= 5
ORDER BY MDSYS.SDO_NN_DISTANCE(1);
